from .utils import resize_image

"""
ResiCLI: A Command-Line Image Resizing Tool
"""

__version__ = "0.1.0"

# Import key modules or functions for ease of access
from .cli import main
from .utils import resize_image

# Optional: Provide a friendly name for the package
name = "ResiCLI"
